Protein Blocks related data — pbxplore.PB — PBxplore 1.1 documentation

# Protein Blocks related data — `pbxplore.PB`

## Protein blocks definition

- `REFERENCES` The definition of each block as a dictionary; each key is a block name (as a lower case letter), and each value is a list of the dihedral angle values that define the block.
- `NAMES` The names of all the protein blocks.

## Substitution matrix

- `SUBSTITUTION_MATRIX_NAME` The absolute path to the file that contains the subtitution matrix

`pbxplore.PB.` `load_substitution_matrix`(name)

  Load PB substitution matrix.

  The matrix must be 16x16.

  Parameters: | name (str) – Name of the file containing the PBs susbtitution matrix.
  Returns: | mat – Array of floats.
  Return type: | numpy array
  Raises: | `InvalidBlockError` – encountered an unexpected PB

## Exceptions

exception `pbxplore.PB.` `SizeError`

  Exception raised when a sequence does not have the expected length.

exception `pbxplore.PB.` `InvalidBlockError`(block=None)

  Exception raised when encounter an invalid protein block.